;-----------------------------------------------------------------------
; AutoHotkey script to read the XML summary file written by Breeze Systems' photo booth software
; and append the data to a CSV log file that can be read into a spreadsheet and then optionally
; move the XML file to the logs directory.
;
; Usage: Set PhotoboothStatusCmdXML and PhotoboothStatusCmd in the Windows registry to run this
; script either by compiling the script and running the executable e.g
; PhotoboothStatusCmdXML = D:\photobooth_log.exe
; or by invoking AutoHotKey e.g.
; PhotoboothStatusCmdXML = "C:\Program Files\AutoHotkey\AutoHotkey.exe" D:\photobooth_log.ahk
; Please see the help files for information on setting PhotoboothStatusCmd and PhotoboothStatusCmdXML
;
; AutoHotKey is free and can be downloaded from:
; http://www.autohotkey.com
;
; This script works with:
; DSLR Remote Pro for Windows v2.2.1 or later
; NKRemote v2.2.1 or later
; PSRemote v2.1.1 or later
; Webcam Photobooth v1.0.1 or later
;
; This script comes with no warranty or support whatsoever and may
; be freely copied or modified as required.
;
; Written by Chris Breeze, www.breezesys.com
;-----------------------------------------------------------------------

; Set MoveXmlFileToLogsDir to 1 to move the XML file to the logs directory:
MoveXmlFileToLogsDir = 0

#NoEnv  ; Recommended for performance and compatibility with future AutoHotkey releases.
#SingleInstance force
SendMode Input  ; Recommended for new scripts due to its superior speed and reliability.
SetWorkingDir %A_ScriptDir%  ; Ensures a consistent starting directory.

IfExist, %1%
{
	; Extract filename and directory from XML pathname
	dir = %1%
	RegExMatch(dir, "([^\\]+)$", filename) 
	RegExMatch(dir, "(.*)\\", dir) 

	FileRead, Contents, %1%
	RegExMatch(Contents, "<date>(.*)</date>", date_taken) 
	RegExMatch(Contents, "<time>(.*)</time>", time_taken) 
	RegExMatch(Contents, "<prints>(.*)</prints>", prints) 
	RegExMatch(Contents, "<user_data>(.*)</user_data>", email) 
	RegExMatch(Contents, "<user_data2>(.*)</user_data2>", name) 

	; Define output dir for CSV log file and create if necessary
	dir := dir . "logs"
	FileCreateDir %dir%

	; Append date,time,prints,email,name to photobooth.csv file in logs subfolder
	FileAppend,
(
%date_taken1%,%time_taken1%,%prints1%,%email1%,%name1%`n
),%dir%\photobooth.csv

	if MoveXmlFileToLogsDir
	{
		FileMove, %1%, %dir%\%filename%
	}
}
