;-----------------------------------------------------------------------
; AutoHotkey script to switch between Webcam Photobooth in video booth
; mode and DSLR Remote Pro for Windows, NKRemote or PSRemote in stills
; photobooth mode. This is so that a webcam can be used for the video
; capture and a Canon DSLR, Nikon DSLR or Canon PowerShot camera can be
; used for the stills photoboth images.
;
; The following keyboard shortcuts are used:
; Ctrl+V - Switch to video booth using Webcam Photobooth
; Ctrl+P - Switch to stills photobooth
; Ctrl+S - Toggle between stills photobooth and video booth
;
; To use:
; 1) run this script by double clicking on it in Windows Explorer
; 2) run Webcam Photobooth and put it into full screen photobooth mode
;    with video booth mode active.
; 3) run DSLR Remote Pro/NKRemote/PSRemote and put it into full screen
;    photobooth mode. 
; 
; AutoHotKey is free and can be downloaded from:
; http://www.autohotkey.com
;
; This script comes with no warranty or support whatsoever and may
; be freely copied or modified as required.
;
; Written by Chris Breeze, www.breezesys.com
;-----------------------------------------------------------------------

#SingleInstance force
#NoEnv  ; Recommended for performance and compatibility with future AutoHotkey releases.
SendMode Input  ; Recommended for new scripts due to its superior speed and reliability.
SetWorkingDir %A_ScriptDir%  ; Ensures a consistent starting directory.
SetTitleMatchMode, 2

; Only intercept Ctrl+v, Ctrl+p and Ctrl+s if photobooth software is running in full
; screen mode
#IfWinExist Breeze Systems Photobooth

;**********************
;* Ctrl+V             *
;* Select video booth *
;**********************
^v::
readyId := WinExist("\ready.jpg")
videoReadyId := WinExist("\video_ready.jpg")
standbyId := WinExist("\welcome.jpg")
if %readyId%
{
   if %videoReady%
   {
      ; put stills photo booth window into standby mode
      WinActivate, ahk_id %readyId%
      SendInput {F6}

      ; video booth is ready and so we just need to make it active
      WinActivate, ahk_id %videoReadyId%
   }
   else if %standbyId%
   {
      ; put stills photo booth window into standby mode
      WinActivate, ahk_id %readyId%
      SendInput {F6}

      ; make video booth window active and take it out of standby
      WinActivate, ahk_id %standbyId%
      SendInput {F6}
   }
}
return

;*****************************
;* Ctrl+P                    *
;* Select stills photo booth *
;*****************************
^p::
readyId := WinExist("\ready.jpg")
videoReadyId := WinExist("\video_ready.jpg")
standbyId := WinExist("\welcome.jpg")
if %videoReadyId%
{
   if %readyId%
   {
      ; put video booth window into standby mode
      WinActivate, ahk_id %videoReadyId%
      SendInput {F6}

      ; stills photo booth is ready and so we just need to make it active
      WinActivate, ahk_id %readyId%
   }
   else if %standbyId%
   {
      ; put video booth window into standby mode
      WinActivate, ahk_id %videoReadyId%
      SendInput {F6}

      ; make photo booth window active and take it out of standby
      WinActivate, ahk_id %standbyId%
      SendInput {F6}
   }
}
return

;*****************************************************
;* Ctrl+S                                            *
;* Toggle between stills photo booth and video booth *
;*****************************************************
^s::
readyId := WinExist("\ready.jpg")
videoReadyId := WinExist("\video_ready.jpg")
standbyId := WinExist("\welcome.jpg")
if %videoReadyId%
{
   if %readyId%
   {
      ; put video booth window into standby mode
      WinActivate, ahk_id %videoReadyId%
      SendInput {F6}

      ; stills photo booth is ready and so we just need to make it active
      WinActivate, ahk_id %readyId%
   }
   else if %standbyId%
   {
      ; put video booth window into standby mode
      WinActivate, ahk_id %videoReadyId%
      SendInput {F6}

      ; make photo booth window active and take it out of standby
      WinActivate, ahk_id %standbyId%
      SendInput {F6}
   }
}
else if %readyId%
{
   if %standbyId%
   {
      ; put stills photo booth window into standby mode
      WinActivate, ahk_id %readyId%
      SendInput {F6}

      ; make video booth window active and take it out of standby
      WinActivate, ahk_id %standbyId%
      SendInput {F6}
   }
}
return
